#[non_exhaustive]pub enum TelegramError {
}Expand description
Base error type for all Telegram Bot API errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Forbidden(String)
The bot doesn’t have enough rights to perform the requested action.
InvalidToken(String)
The provided token is invalid.
EndPointNotFound(String)
The requested API endpoint was not found.
Network(String)
A network-level error occurred.
BadRequest(String)
Telegram returned a 400 Bad Request response.
TimedOut(String)
The request timed out.
ChatMigrated
The chat was migrated to a supergroup with a new ID.
RetryAfter
Flood control – must wait before retrying.
Conflict(String)
A long-poll or webhook conflicts with another one.
PassportDecryption(String)
Passport decryption failed.
Http(Error)
HTTP-level error from reqwest.
Json(Error)
JSON serialization/deserialization error.
Io(Error)
I/O error.
Implementations
Sourceimpl TelegramError
impl TelegramError
Sourcepub fn from_api_message(message: &str) -> String
pub fn from_api_message(message: &str) -> String
Cleans the error prefix from API error messages, matching python-telegram-bot behavior.