#[non_exhaustive]pub enum HandlerError {
HandlerStop {
state: Option<Value>,
},
Other(Box<dyn Error + Sync + Send>),
}Expand description
Errors that can occur during update processing.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
HandlerStop
A handler explicitly requested dispatch to stop, optionally carrying state.
Other(Box<dyn Error + Sync + Send>)
A wrapped error from a handler or Telegram API call.