FnHandler

Struct FnHandler 

pub struct FnHandler { /* private fields */ }
A lightweight handler that pairs a predicate with an async callback.

FnHandler bridges the gap between raw application::Handler structs and the typed handler trait system. It implements Handler so it can be registered via [Application::add_handler].

Examples

use rust_tg_bot::ext::prelude::*;
use rust_tg_bot::ext::handlers::base::FnHandler;

async fn button_handler(update: Update, context: Context) -> HandlerResult {
    // handle callback query ...
    Ok(())
}

// Register with a predicate:
app.add_handler(
    FnHandler::new(|u| u.callback_query().is_some(), button_handler),
    0,
).await;

// Or use a convenience constructor:
app.add_handler(FnHandler::on_callback_query(button_handler), 0).await;

Implementations

Source

impl FnHandler

pub fn new<C, Cb, Fut>(check: C, callback: Cb) -> FnHandler
where C: Fn(&Update) -> bool + Send + Sync + 'static, Cb: Fn(Arc<Update>, CallbackContext) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<(), HandlerError>> + Send + 'static,

Create a new FnHandler with a custom predicate and an async callback.

The callback receives (Update, CallbackContext) and returns Result<(), HandlerError>.

pub fn on_callback_query<Cb, Fut>(callback: Cb) -> FnHandler
where Cb: Fn(Arc<Update>, CallbackContext) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<(), HandlerError>> + Send + 'static,

Match updates that have a callback_query.

pub fn on_inline_query<Cb, Fut>(callback: Cb) -> FnHandler
where Cb: Fn(Arc<Update>, CallbackContext) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<(), HandlerError>> + Send + 'static,

Match updates that have an inline_query.

pub fn on_poll<Cb, Fut>(callback: Cb) -> FnHandler
where Cb: Fn(Arc<Update>, CallbackContext) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<(), HandlerError>> + Send + 'static,

Match updates that have a poll.

pub fn on_poll_answer<Cb, Fut>(callback: Cb) -> FnHandler
where Cb: Fn(Arc<Update>, CallbackContext) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<(), HandlerError>> + Send + 'static,

Match updates that have a poll_answer.

pub fn on_shipping_query<Cb, Fut>(callback: Cb) -> FnHandler
where Cb: Fn(Arc<Update>, CallbackContext) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<(), HandlerError>> + Send + 'static,

Match updates that have a shipping_query.

pub fn on_pre_checkout_query<Cb, Fut>(callback: Cb) -> FnHandler
where Cb: Fn(Arc<Update>, CallbackContext) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<(), HandlerError>> + Send + 'static,

Match updates that have a pre_checkout_query.

pub fn on_chat_member<Cb, Fut>(callback: Cb) -> FnHandler
where Cb: Fn(Arc<Update>, CallbackContext) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<(), HandlerError>> + Send + 'static,

Match updates that have a chat_member.

pub fn on_my_chat_member<Cb, Fut>(callback: Cb) -> FnHandler
where Cb: Fn(Arc<Update>, CallbackContext) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<(), HandlerError>> + Send + 'static,

Match updates that have a my_chat_member.

pub fn on_message<Cb, Fut>(callback: Cb) -> FnHandler
where Cb: Fn(Arc<Update>, CallbackContext) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<(), HandlerError>> + Send + 'static,

Match updates that have a message.

pub fn on_any<Cb, Fut>(callback: Cb) -> FnHandler
where Cb: Fn(Arc<Update>, CallbackContext) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<(), HandlerError>> + Send + 'static,

Match every update (catch-all).