#[non_exhaustive]pub struct ForceReply {
pub force_reply: bool,
pub selective: Option<bool>,
pub input_field_placeholder: Option<String>,
}Expand description
Upon receiving a message with this object, Telegram clients will display a reply interface to the user (act as if the user has selected the bot’s message and tapped ‘Reply’).
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.force_reply: boolShows reply interface to the user, as if they manually selected the bot’s message and
tapped ‘Reply’. Always true.
selective: Option<bool>If true, force reply only from specific @mentioned users or the sender of the message
being replied to.
input_field_placeholder: Option<String>Placeholder shown in the input field when the reply is active; 1-64 characters.
Implementations
Sourceimpl ForceReply
impl ForceReply
Sourcepub fn new() -> ForceReply
pub fn new() -> ForceReply
Creates a new ForceReply with force_reply set to true.
Sourcepub fn selective(self) -> ForceReply
pub fn selective(self) -> ForceReply
Show the force reply to specific users only.
Sourcepub fn placeholder(self, text: impl Into<String>) -> ForceReply
pub fn placeholder(self, text: impl Into<String>) -> ForceReply
Set a placeholder shown in the input field when the reply is active.