#[non_exhaustive]pub struct InlineKeyboardMarkup {
pub inline_keyboard: Vec<Vec<InlineKeyboardButton>>,
}Expand description
An inline keyboard that appears right next to the message it belongs to.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.inline_keyboard: Vec<Vec<InlineKeyboardButton>>Array of button rows, each represented by an array of InlineKeyboardButton objects.
Implementations
Sourceimpl InlineKeyboardMarkup
impl InlineKeyboardMarkup
Sourcepub fn new(rows: Vec<Vec<InlineKeyboardButton>>) -> InlineKeyboardMarkup
pub fn new(rows: Vec<Vec<InlineKeyboardButton>>) -> InlineKeyboardMarkup
Create a new inline keyboard from rows of buttons.
Create an inline keyboard with a single button.
Sourcepub fn from_row(buttons: Vec<InlineKeyboardButton>) -> InlineKeyboardMarkup
pub fn from_row(buttons: Vec<InlineKeyboardButton>) -> InlineKeyboardMarkup
Create an inline keyboard with a single row of buttons.
Sourcepub fn from_column(buttons: Vec<InlineKeyboardButton>) -> InlineKeyboardMarkup
pub fn from_column(buttons: Vec<InlineKeyboardButton>) -> InlineKeyboardMarkup
Create an inline keyboard where each button is on its own row (vertical layout).