#[non_exhaustive]pub struct ReplyKeyboardRemove {
pub remove_keyboard: bool,
pub selective: Option<bool>,
}Expand description
Upon receiving a message with this object, Telegram clients will remove the current custom keyboard and display the default letter-keyboard.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.remove_keyboard: boolRequests clients to remove the custom keyboard. Always true.
selective: Option<bool>true to remove the keyboard for specific users only.
Implementations
Sourceimpl ReplyKeyboardRemove
impl ReplyKeyboardRemove
Sourcepub fn new() -> ReplyKeyboardRemove
pub fn new() -> ReplyKeyboardRemove
Creates a new ReplyKeyboardRemove with remove_keyboard set to true.
Sourcepub fn selective(self) -> ReplyKeyboardRemove
pub fn selective(self) -> ReplyKeyboardRemove
Remove the keyboard for specific users only.