Update

Struct Update 

#[non_exhaustive]
pub struct Update { pub update_id: i64, pub kind: UpdateKind, }
This object represents an incoming update.

Corresponds to the Bot API Update object.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
update_id: i64

The update’s unique identifier. Update identifiers start from a certain positive number and increase sequentially.

kind: UpdateKind

The payload carried by the update.

Implementations

Source

impl Update

pub fn message(&self) -> Option<&Message>

Returns the message payload for message-like update kinds.

pub fn edited_message(&self) -> Option<&Message>

Returns the payload if this update is of the corresponding variant.

pub fn channel_post(&self) -> Option<&Message>

Returns the payload if this update is of the corresponding variant.

pub fn edited_channel_post(&self) -> Option<&Message>

Returns the payload if this update is of the corresponding variant.

pub fn business_connection(&self) -> Option<&BusinessConnection>

Returns the payload if this update is of the corresponding variant.

pub fn business_message(&self) -> Option<&Message>

Returns the payload if this update is of the corresponding variant.

pub fn edited_business_message(&self) -> Option<&Message>

Returns the payload if this update is of the corresponding variant.

pub fn deleted_business_messages(&self) -> Option<&BusinessMessagesDeleted>

Returns the payload if this update is of the corresponding variant.

pub fn inline_query(&self) -> Option<&InlineQuery>

Returns the payload if this update is of the corresponding variant.

pub fn chosen_inline_result(&self) -> Option<&ChosenInlineResult>

Returns the payload if this update is of the corresponding variant.

pub fn callback_query(&self) -> Option<&CallbackQuery>

Returns the payload if this update is of the corresponding variant.

pub fn shipping_query(&self) -> Option<&ShippingQuery>

Returns the payload if this update is of the corresponding variant.

pub fn pre_checkout_query(&self) -> Option<&PreCheckoutQuery>

Returns the payload if this update is of the corresponding variant.

pub fn purchased_paid_media(&self) -> Option<&PaidMediaPurchased>

Returns the payload if this update is of the corresponding variant.

pub fn poll(&self) -> Option<&Poll>

Returns the payload if this update is of the corresponding variant.

pub fn poll_answer(&self) -> Option<&PollAnswer>

Returns the payload if this update is of the corresponding variant.

pub fn my_chat_member(&self) -> Option<&ChatMemberUpdated>

Returns the payload if this update is of the corresponding variant.

pub fn chat_member(&self) -> Option<&ChatMemberUpdated>

Returns the payload if this update is of the corresponding variant.

pub fn chat_join_request(&self) -> Option<&ChatJoinRequest>

Returns the payload if this update is of the corresponding variant.

pub fn chat_boost(&self) -> Option<&ChatBoostUpdated>

Returns the payload if this update is of the corresponding variant.

pub fn removed_chat_boost(&self) -> Option<&ChatBoostRemoved>

Returns the payload if this update is of the corresponding variant.

pub fn message_reaction(&self) -> Option<&MessageReactionUpdated>

Returns the payload if this update is of the corresponding variant.

pub fn message_reaction_count(&self) -> Option<&MessageReactionCountUpdated>

Returns the payload if this update is of the corresponding variant.

pub fn managed_bot(&self) -> Option<&ManagedBotUpdated>

Returns the payload if this update is of the corresponding variant.

pub fn effective_user(&self) -> Option<&User>

Returns a reference to the User that sent this update, regardless of update type.

Returns None for updates that have no associated user (channel posts, polls, chat boosts, removed chat boosts, message reaction count, deleted business messages).

Mirrors Python’s Update.effective_user property.

pub fn effective_chat(&self) -> Option<&Chat>

Returns a reference to the Chat in which this update occurred, if any.

Returns None for updates with no associated chat (inline queries, chosen inline results, shipping/pre-checkout queries, polls, poll answers, business connections, purchased paid media, managed bot updates).

Mirrors Python’s Update.effective_chat property.

pub fn effective_message(&self) -> Option<&Message>

Returns a reference to the Message carried by this update, if any.

Considers message, edited_message, channel_post, edited_channel_post, the message inside callback_query, business_message, and edited_business_message.

For callback queries where the message is inaccessible (date == 0), this returns None for the callback query branch.

Mirrors Python’s Update.effective_message property.