MaybeInaccessibleMessage

Enum MaybeInaccessibleMessage 

#[non_exhaustive]
pub enum MaybeInaccessibleMessage { Message(Box<Message>), Inaccessible(Box<InaccessibleMessage>), }
Union type: either a full Message or an InaccessibleMessage.

Discriminated by whether date == 0 (inaccessible) or not.

Corresponds to the Bot API MaybeInaccessibleMessage type.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Message(Box<Message>)

A regular, accessible message (date != 0).



Inaccessible(Box<InaccessibleMessage>)

A deleted or otherwise inaccessible message (date == 0).

Implementations

Source

impl MaybeInaccessibleMessage

pub fn chat(&self) -> &Chat

Returns a reference to the Chat regardless of variant.

pub fn message_id(&self) -> i64

Returns the message id regardless of variant.

pub fn as_message(&self) -> Option<&Message>

Returns a reference to the inner Message if accessible, None otherwise.