Module poll

Module poll 

Poll and poll answer types.

Structs

InputPollOption
One answer option in a poll to be sent.
Poll
Information about a poll.
PollAnswer
An answer of a user in a non-anonymous poll.
PollOption
One answer option in a received poll.
PollOptionAdded
Service message about an option added to a poll.
PollOptionDeleted
Service message about an option deleted from a poll.