#[non_exhaustive]pub struct InputPollOption {
pub text: String,
pub text_parse_mode: Option<String>,
pub text_entities: Option<Vec<MessageEntity>>,
}Expand description
One answer option in a poll to be sent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.text: StringOption text; 1-100 characters.
text_parse_mode: Option<String>Mode for parsing entities in the text.
text_entities: Option<Vec<MessageEntity>>Special entities that appear in the option text.
Implementations
Sourceimpl InputPollOption
impl InputPollOption
Sourcepub fn new(text: impl Into<String>) -> InputPollOption
pub fn new(text: impl Into<String>) -> InputPollOption
Creates a new instance with the given required fields; optional fields
are initialised to their Default values.