#[non_exhaustive]pub struct PollAnswer {
pub poll_id: String,
pub option_ids: Vec<i64>,
pub user: Option<User>,
pub voter_chat: Option<Chat>,
pub option_persistent_ids: Option<Vec<String>>,
}Expand description
An answer of a user in a non-anonymous poll.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.poll_id: StringUnique poll identifier.
option_ids: Vec<i64>Identifiers of answer options chosen by the user. May be empty if the user retracted their vote.
user: Option<User>The user that changed the answer to the poll, if the voter isn’t anonymous.
voter_chat: Option<Chat>The chat that changed the answer to the poll, if the voter is anonymous.
option_persistent_ids: Option<Vec<String>>Persistent identifiers of the chosen options.
Added in Bot API 9.6.