#[non_exhaustive]pub struct PollOptionAdded {
pub poll_message: Option<Box<Message>>,
pub option_persistent_id: String,
pub option_text: String,
pub option_text_entities: Option<Vec<MessageEntity>>,
}Expand description
Service message about an option added to a poll.
Corresponds to the Bot API PollOptionAdded object.
Added in Bot API 9.6.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.poll_message: Option<Box<Message>>Message containing the poll to which the option was added, if known.
Note that the Message object in this field will not contain the reply_to_message
field even if it itself is a reply.
option_persistent_id: StringUnique identifier of the added option.
option_text: StringOption text.
option_text_entities: Option<Vec<MessageEntity>>Special entities that appear in the option text.