Module reply

Module reply 

Reply parameters type.

Structs

ExternalReplyInfo
Information about a message that is being replied to, which may come from another chat or forum topic.
ReplyParameters
Reply parameters for the message that is being sent.
TextQuote
The quoted part of a message that is replied to by the given message.