#[non_exhaustive]pub struct TextQuote {
pub text: String,
pub position: i64,
pub entities: Option<Vec<MessageEntity>>,
pub is_manual: Option<bool>,
}Expand description
The quoted part of a message that is replied to by the given message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.text: StringText of the quoted part of a message that is replied to by the given message.
position: i64Approximate quote position in the original message in UTF-16 code units.
entities: Option<Vec<MessageEntity>>Special entities that appear in the quote.
is_manual: Option<bool>true if the quote was chosen manually by the message sender.
Implementations