Module shared

Module shared 

Shared user and chat types.

Structs

ChatShared
Information about a chat shared with the bot via a KeyboardButtonRequestChat button.
SharedUser
Information about a user shared with the bot via a KeyboardButtonRequestUsers button.
UsersShared
Information about users shared with the bot via a KeyboardButtonRequestUsers button.