#[non_exhaustive]pub struct ChatShared {
pub request_id: i64,
pub chat_id: i64,
pub title: Option<String>,
pub username: Option<String>,
pub photo: Option<Vec<PhotoSize>>,
}Expand description
Information about a chat shared with the bot via a KeyboardButtonRequestChat button.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.request_id: i64Identifier of the request.
chat_id: i64Identifier of the shared chat.
title: Option<String>Title of the chat, if requested by the bot.
username: Option<String>Username of the chat, if requested by the bot and available.
photo: Option<Vec<PhotoSize>>Available sizes of the chat photo, if requested by the bot.