#[non_exhaustive]pub struct SharedUser {
pub user_id: i64,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub username: Option<String>,
pub photo: Option<Vec<PhotoSize>>,
}Expand description
Information about a user shared with the bot via a KeyboardButtonRequestUsers button.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.user_id: i64Identifier of the shared user.
first_name: Option<String>First name of the user, if requested by the bot.
last_name: Option<String>Last name of the user, if requested by the bot.
username: Option<String>Username of the user, if requested by the bot.
photo: Option<Vec<PhotoSize>>Available sizes of the user’s photo, if requested by the bot.