UpdateKind

Enum UpdateKind 

#[non_exhaustive]
pub enum UpdateKind {
Show 25 variants Message(Message), EditedMessage(Message), ChannelPost(Message), EditedChannelPost(Message), BusinessConnection(BusinessConnection), BusinessMessage(Message), EditedBusinessMessage(Message), DeletedBusinessMessages(BusinessMessagesDeleted), InlineQuery(InlineQuery), ChosenInlineResult(ChosenInlineResult), CallbackQuery(CallbackQuery), ShippingQuery(ShippingQuery), PreCheckoutQuery(PreCheckoutQuery), PurchasedPaidMedia(PaidMediaPurchased), Poll(Poll), PollAnswer(PollAnswer), MyChatMember(ChatMemberUpdated), ChatMember(ChatMemberUpdated), ChatJoinRequest(ChatJoinRequest), ChatBoost(ChatBoostUpdated), RemovedChatBoost(ChatBoostRemoved), MessageReaction(MessageReactionUpdated), MessageReactionCount(MessageReactionCountUpdated), ManagedBot(ManagedBotUpdated), Unknown,
}
The payload carried by an incoming Update.

Telegram sends update kinds as a single top-level key such as message, callback_query, or poll. This enum preserves that wire format via a custom serde implementation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Message(Message)

New incoming message of any kind – text, photo, sticker, etc.



EditedMessage(Message)

New version of a message that is known to the bot and was edited.



ChannelPost(Message)

New incoming channel post of any kind – text, photo, sticker, etc.



EditedChannelPost(Message)

New version of a channel post that is known to the bot and was edited.



BusinessConnection(BusinessConnection)

The bot was connected to or disconnected from a business account.



BusinessMessage(Message)

New non-service message from a connected business account.



EditedBusinessMessage(Message)

New version of a message from a connected business account.



DeletedBusinessMessages(BusinessMessagesDeleted)

Messages were deleted from a connected business account.



InlineQuery(InlineQuery)

New incoming inline query.



ChosenInlineResult(ChosenInlineResult)

The result of an inline query that was chosen by a user.



CallbackQuery(CallbackQuery)

New incoming callback query.



ShippingQuery(ShippingQuery)

New incoming shipping query.



PreCheckoutQuery(PreCheckoutQuery)

New incoming pre-checkout query.



PurchasedPaidMedia(PaidMediaPurchased)

A user purchased paid media.



Poll(Poll)

New poll state.



PollAnswer(PollAnswer)

A user changed their answer in a non-anonymous poll.



MyChatMember(ChatMemberUpdated)

The bot’s chat member status was updated in a chat.



ChatMember(ChatMemberUpdated)

A chat member’s status was updated in a chat.



ChatJoinRequest(ChatJoinRequest)

A request to join the chat has been sent.



ChatBoost(ChatBoostUpdated)

A chat boost was added or changed.



RemovedChatBoost(ChatBoostRemoved)

A boost was removed from a chat.



MessageReaction(MessageReactionUpdated)

A reaction to a message was changed by a user.



MessageReactionCount(MessageReactionCountUpdated)

Reactions to a message with anonymous reactions were changed.



ManagedBot(ManagedBotUpdated)

A managed bot was created or updated.



Unknown

Unknown or unsupported update types, or an update with no payload fields.