Telegram message type.
Telegram [Message] type — ported from python-telegram-bot/src/telegram/_message.py.
All 80+ optional fields from the Python source are represented. Only data fields are included. No Bot reference, no API shortcuts.
Required fields
message_iddatechat
Everything else is Option<T> apart from a small set of defaulted boolean flags.
Structs
- Inaccessible
Message - Describes a message that was deleted or is otherwise inaccessible to the bot.
- Message
- This object represents a message.
Enums
- Maybe
Inaccessible Message - Union type: either a full
Messageor anInaccessibleMessage.