Poll and poll answer types.
Structs
- Input
Poll Option - One answer option in a poll to be sent.
- Poll
- Information about a poll.
- Poll
Answer - An answer of a user in a non-anonymous poll.
- Poll
Option - One answer option in a received poll.
- Poll
Option Added - Service message about an option added to a poll.
- Poll
Option Deleted - Service message about an option deleted from a poll.