Reply parameters type.
Structs
- External
Reply Info - Information about a message that is being replied to, which may come from another chat or forum topic.
- Reply
Parameters - Reply parameters for the message that is being sent.
- Text
Quote - The quoted part of a message that is replied to by the given message.