#[non_exhaustive]pub struct ExternalReplyInfo {Show 25 fields
pub origin: MessageOrigin,
pub chat: Option<Chat>,
pub message_id: Option<i64>,
pub link_preview_options: Option<LinkPreviewOptions>,
pub animation: Option<Animation>,
pub audio: Option<Audio>,
pub document: Option<Document>,
pub photo: Option<Vec<PhotoSize>>,
pub sticker: Option<Sticker>,
pub story: Option<Story>,
pub video: Option<Video>,
pub video_note: Option<VideoNote>,
pub voice: Option<Voice>,
pub has_media_spoiler: Option<bool>,
pub checklist: Option<Checklist>,
pub contact: Option<Contact>,
pub dice: Option<Dice>,
pub game: Option<Game>,
pub giveaway: Option<Giveaway>,
pub giveaway_winners: Option<GiveawayWinners>,
pub invoice: Option<Invoice>,
pub location: Option<Location>,
pub poll: Option<Poll>,
pub venue: Option<Venue>,
pub paid_media: Option<PaidMediaInfo>,
}Expand description
Information about a message that is being replied to, which may come from another chat or forum topic.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.origin: MessageOriginOrigin of the message replied to by the given message.
chat: Option<Chat>Chat the original message belongs to. Available only if the chat is a supergroup or a channel.
message_id: Option<i64>Unique message identifier inside the original chat.
link_preview_options: Option<LinkPreviewOptions>Options used for link preview generation for the original message, if it is a text message.
animation: Option<Animation>Message is an animation.
audio: Option<Audio>Message is an audio file.
document: Option<Document>Message is a general file.
photo: Option<Vec<PhotoSize>>Message is a photo; available sizes of the photo.
sticker: Option<Sticker>Message is a sticker.
story: Option<Story>Message is a forwarded story.
video: Option<Video>Message is a video.
video_note: Option<VideoNote>Message is a video note.
voice: Option<Voice>Message is a voice message.
has_media_spoiler: Option<bool>true if the message media is covered by a spoiler animation.
checklist: Option<Checklist>Message is a checklist.
contact: Option<Contact>Message is a shared contact.
dice: Option<Dice>Message is a dice with random value.
game: Option<Game>Message is a game.
giveaway: Option<Giveaway>Message is a scheduled giveaway.
giveaway_winners: Option<GiveawayWinners>A giveaway with public winners was completed.
invoice: Option<Invoice>Message is an invoice for a payment.
location: Option<Location>Message is a shared location.
poll: Option<Poll>Message is a native poll.
venue: Option<Venue>Message is a venue.
paid_media: Option<PaidMediaInfo>Message contains paid media.