#[non_exhaustive]pub struct ReplyParameters {
pub message_id: i64,
pub chat_id: Option<Value>,
pub allow_sending_without_reply: Option<bool>,
pub quote: Option<String>,
pub quote_parse_mode: Option<String>,
pub quote_entities: Option<Vec<MessageEntity>>,
pub quote_position: Option<i64>,
pub checklist_task_id: Option<i64>,
pub poll_option_id: Option<String>,
}Expand description
Reply parameters for the message that is being sent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message_id: i64Identifier of the message that will be replied to in the current chat, or in the chat
chat_id if it is specified.
chat_id: Option<Value>If the message to be replied to is from a different chat, the identifier or username of that chat. Kept as Value since it can be either an integer chat id or a string username.
allow_sending_without_reply: Option<bool>Pass true if the message should be sent even if the specified message to be replied to
is not found.
quote: Option<String>Quoted part of the message to be replied to; 0-1024 characters after entities parsing.
quote_parse_mode: Option<String>Mode for parsing entities in the quote.
quote_entities: Option<Vec<MessageEntity>>Special entities that appear in the quote.
quote_position: Option<i64>Position of the quote in the original message in UTF-16 code units.
checklist_task_id: Option<i64>Identifier of the specific checklist task to be replied to.
poll_option_id: Option<String>Identifier of the specific poll option to be replied to.
Added in Bot API 9.6.
Implementations
Sourceimpl ReplyParameters
impl ReplyParameters
Sourcepub fn new(message_id: impl Into<i64>) -> ReplyParameters
pub fn new(message_id: impl Into<i64>) -> ReplyParameters
Creates a new instance with the given required fields; optional fields
are initialised to their Default values.