Shared user and chat types.
Structs
- Chat
Shared - Information about a chat shared with the bot via a
KeyboardButtonRequestChatbutton. - Shared
User - Information about a user shared with the bot via a
KeyboardButtonRequestUsersbutton. - Users
Shared - Information about users shared with the bot via a
KeyboardButtonRequestUsersbutton.